/* This file is part of wtmpclean', a tool for hacking the wtmp databases
 * Copyright (C) 2008 by Davide Madrisan <davide.madrisan@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef WTMPCLEAN_H
#define WTMPCLEAN_H

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#if defined(HAVE_UTMPXNAME)
# define UTMPXNAME(wtmpfile) utmpxname(wtmpfile)
#elif defined(HAVE_UTMPNAME)
# define UTMPXNAME(wtmpfile) utmpname(wtmpfile);
#endif

#ifdef _PATH_WTMPX
/* Linux (glibc 2) */
# define DEFAULT_WTMP _PATH_WTMPX
#else
# ifdef _PATH_WTMP
/* Linux, FreeBSD, OpenBSD */
#  define DEFAULT_WTMP _PATH_WTMP
# else
#  ifdef WTMP_FILE
/* AIX */
#   define DEFAULT_WTMP WTMP_FILE
#  endif
# endif
#endif

#define SECDAY (24*60*60)       /* seconds in a day */

/* Types of listing */
#define R_NORMAL   1 /* Normal */
#define R_NOW      2 /* Still logged in */
#define R_REBOOT   3 /* Reboot record */
#define R_PHANTOM  4 /* No logout record but session is stale */

/* Double linked list of struct utmpx's */
struct utmpxlist
{
    struct utmpx ut;
    time_t eos;                 /* end of session */
    time_t delta;               /* time difference */
    struct utmpxlist *prev, *next;
};

void usage (int status);
void die (char *msg, int err);
void listentry (struct utmpxlist *p, int what);
void wtmpxlist (const char *wtmpfile, const char *user);
unsigned int wtmpedit (const char *wtmpfile, const char *user,
                       unsigned int preserve, struct tm *u, unsigned int *cleanerr);

#endif /* WTMPCLEAN_H */
